@@ -53,6 +53,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
     m_conStarted = false;
     m_createSubc = false;
     m_acceptKeys = true;
+    m_batchProcess = 0;
 
     m_board = NULL;
     m_newConnector = NULL;
@@ -166,9 +167,9 @@ void Circuit::loadStrDoc( QString &doc )
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
     QList<Linkable*> linkList;   // Linked  Component list
-    QList<Component*> compList;   // Pasting Component list
-    QList<Connector*> conList;    // Pasting Connector list
-    QList<Node*> nodeList;        // Pasting node list
+    QSet<Component*> compList;   // Pasting Component list
+    QSet<Connector*> conList;    // Pasting Connector list
+    QSet<Node*> nodeList;        // Pasting node list
 
     m_newComp = NULL;
     Component* lastComp = NULL;
@@ -322,7 +323,7 @@ void Circuit::loadStrDoc( QString &doc )
                     if( newUid.isEmpty() ) newUid = "connector-"+newConnectorId();
                     Connector* con = new Connector( type, newUid, startpin, endpin );
                     con->setPointList( pointList );
-                    conList.append( con );
+                    conList.insert( con );
                     m_newComp = con;
                     if( !rev ){
                         startpin->isMoved();
@@ -357,7 +358,7 @@ void Circuit::loadStrDoc( QString &doc )
                 int number = joint->getUid().split("-").last().toInt();
                 if( number > m_seqNumber ) m_seqNumber = number; // Adjust item counter: m_seqNumber
                 addItem( joint );
-                nodeList.append( joint );
+                nodeList.insert( joint );
                 m_newComp = joint;
                 m_compMap[newUid] = joint;
             }
@@ -433,7 +434,7 @@ void Circuit::loadStrDoc( QString &doc )
                     if( m_pasting ) comp->setIdLabel( newUid );
                     comp->updtLabelPos();
                     comp->updtValLabelPos();
-                    compList.append( comp );
+                    compList.insert( comp );
                     if( comp->m_linkable )
                     {
                         Linkable* l = dynamic_cast<Linkable*>(comp);
@@ -453,14 +454,33 @@ void Circuit::loadStrDoc( QString &doc )
     for( Linkable* l : linkList )
         l->createLinks( &compList );
 
-    m_compList.append( compList );
-    m_nodeList.append( nodeList );
-    m_conList.append( conList );
+    m_compList.unite( compList );
+    m_nodeList.unite( nodeList );
+    m_conList.unite( conList );
+
+    if( m_pasting && !compList.isEmpty() )  {
+        beginBatchProcess();
+
+        // clear all state generated by copy component properties
+        addCompState( NULL, "New State", stateNew);
+
+        // save states
+        for( Component *comp : compList ) addCompState( comp, COMP_STATE_CREATED, stateAdd);
+        for( Node *node : nodeList ) addCompState( node, COMP_STATE_CREATED, stateAdd);
+        for( Connector *con : conList ) addCompState( con, COMP_STATE_CREATED, stateAdd);
+
+    } else {
+        if( !m_undo && !m_redo )  for( Node* joint : nodeList ) joint->checkRemove(); // Only removed if some missing connector
+    }
 
     // Take care about unconnected Joints
-    if( !m_undo && !m_redo )  for( Node* joint : nodeList ) joint->checkRemove(); // Only removed if some missing connector
     for( ShieldSubc* shield : shieldList ) shield->connectBoard();
 
+    if( m_pasting && !compList.isEmpty() )  {
+        saveState();
+        endBatchProcess();
+    }
+
     setAnimate( m_animate ); // Force Pin update
 
     if( m_pasting ) m_idMap.clear();
@@ -493,6 +513,25 @@ QString Circuit::circuitToString()
     return circuit;
 }
 
+void Circuit::clearRemovedComps()
+{
+    for( Connector *con : m_removedConnectors ) delete con;
+    for( Component *comp : m_removedComps ) delete comp;
+    m_removedComps.clear();
+    m_removedConnectors.clear();
+}
+
+void Circuit::addCompRemovedState(const QString &id, const QString &strVal)
+{
+    qDebug() << "Circuit::addCompRemovedState" << id << COMP_STATE_REMOVED;
+    compState cState;
+    cState.component = id;
+    cState.property = COMP_STATE_REMOVED;
+    cState.valStr = strVal;
+    if ( m_undo ) m_circState.compStates.prepend( cState );
+    else m_circState.compStates.append( cState );
+}
+
 bool Circuit::saveString( QString &fileName, QString doc )
 {
     QFile file( fileName );
@@ -570,45 +609,60 @@ void Circuit::removeItems()                     // Remove Selected items
     if( m_conStarted ) return;
     m_busy = true;
 
-    QList<Connector*> connectors;
-    QList<Component*> components;
-    addCompState( NULL, "New State", stateNew );
+    beginBatchProcess();
+    QSet<Connector*> oldConnectors = m_conList;
+    QSet<Component*> oldComponents = m_compList;
+    QSet<Node*> oldNodes = m_nodeList;
 
-    for( QGraphicsItem* item : selectedItems() )
+    //save all comps
+    QMap<CompBase *,QString> compStrMap;
+    for( Connector* con  : oldConnectors ) compStrMap.insert( con, con->toString() );
+    for( Node* node : oldNodes ) compStrMap.insert( node, node->toString() );
+    for( Component* comp : oldComponents ) compStrMap.insert( comp, comp->toString() );
+
+    QList<Connector *> conns;
+    QList<Component *> comps;
+
+    //remove all connectors
+    for( QGraphicsItem* item : selectedItems())
     {
-        if( item->type() == QGraphicsItem::UserType+1 ) // Component
-        {
-            Component* comp = qgraphicsitem_cast<Component* >( item );
-            if( m_compList.contains( comp )
-            && !components.contains( comp ) )
-            {
-                components.append( comp );
-                addCompState( comp, "new", stateAdd );
-
-                for( Pin* pin : comp->getPins() )
-                {
-                    if( !pin ) continue;
-                    Connector* con = pin->connector();
-                    if( con ) addCompState( con, "new", stateAdd );
-                }
-            }
-        }
-        else if( item->type() == QGraphicsItem::UserType+2 ) // ConnectorLine
+        if( item->type() == QGraphicsItem::UserType+2 ) // ConnectorLine
         {
             ConnectorLine* line = qgraphicsitem_cast<ConnectorLine* >( item );
             Connector* con = line->connector();
-            if( !connectors.contains( con ) )
-            {
-                connectors.append( con );
-                addCompState( con, "new", stateAdd );
+            conns.append( con );
+        } else if( item->type() == QGraphicsItem::UserType+1 ) // Component
+        {
+            Component* comp = qgraphicsitem_cast<Component* >( item );
+            comps.append( comp );
+        }
+    }
+    for( Connector* con : conns ) {
+        if ( m_conList.contains( con ) ) removeConnector( con );
+    }
+    for( Component* comp: comps ) {
+        if ( m_compList.contains( comp ) ) {
+            if ( comp->itemType() == "Node" ) {
+                Node * node = dynamic_cast<Node *>(comp);
+                if ( m_nodeList.contains( node ) ) removeNode( node );
+            } else {
+                if ( m_compList.contains( comp ) ) removeComp( comp );
             }
-    }   }
-    if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
-
-    for( Connector* con  : connectors ) con->remove();
-    for( Component* comp : components ) removeComp( comp );
+        }
+    }
+    addCompState( NULL, "New State", stateNew );
+    for( Connector* con  : oldConnectors )  {
+        if ( !m_conList.contains( con ) ) addCompRemovedState( con->getUid(), compStrMap.value(con) );
+    }
+    for( Node* node : oldNodes ) {
+        if ( !m_nodeList.contains( node ) ) addCompRemovedState( node->getUid(), compStrMap.value(node) );
+    }
+    for( Component* comp : oldComponents ) {
+        if ( !m_compList.contains( comp ) ) addCompRemovedState( comp->getUid(), compStrMap.value(comp) );
+    }
     for( QGraphicsItem* item : selectedItems() ) item->setSelected( false );
     saveState();
+    endBatchProcess();
     m_busy = false;
 }
 
@@ -619,10 +673,27 @@ void Circuit::removeComp( Component* comp )
     comp->remove();
     if( !m_compRemoved ) return;
 
-    if( m_compList.contains( comp ) ) m_compList.removeOne( comp );
+    if( m_compList.contains( comp ) ) m_compList.remove( comp );
     if( comp->scene() ) removeItem( comp );
     m_compMap.remove( comp->getUid() );
-    delete comp;
+    m_removedComps.insert( comp );
+}
+
+void Circuit::removeNode( Node* node )
+{
+    if( !m_nodeList.contains(node) ) return;
+    m_nodeList.remove( node );
+    m_compMap.remove( node->getUid() );
+    removeItem( node );
+    m_removedComps.insert( node );
+}
+
+void Circuit::removeConnector( Connector* conn )
+{
+    if (!m_conList.contains(conn)) return;
+    conn->remove();
+    m_conList.remove( conn );
+    m_removedConnectors.insert( conn );
 }
 
 void Circuit::clearCircuit() // Remove everything ( Clear Circuit )
@@ -630,14 +701,19 @@ void Circuit::clearCircuit() // Remove everything ( Clear Circuit )
     if( m_conStarted ) return;
     m_deleting = true;
 
-    while( !m_compList.isEmpty() ) removeComp( m_compList.takeFirst() );
-    while( !m_nodeList.isEmpty() )
+    QSet<Component*> compList = m_compList;
+    for( Component* comp : compList )
     {
-        Node* nod = m_nodeList.takeFirst();
-        if( nod->scene() ) removeItem( nod );
-        delete nod;
+        comp->remove();
+        if( comp->scene() ) removeItem( comp );
+        delete comp;
+    }
+    QSet<Node*> nodeList = m_nodeList;
+    for( Node* node : nodeList )
+    {
+        if( node->scene() ) removeItem( node );
+        delete node;
     }
-    m_pinMap.clear();
     m_deleting = false;
 }
 
@@ -663,8 +739,8 @@ void Circuit::saveState()
     if( m_undo )
     {
         m_redoStack.append( m_circState );
-    }
-    else{                     // Redo or new state
+        m_redoIndex++;
+    } else{                     // Redo or new state
         if( !m_redo ){
             if( m_redoStack.size() )
             {
@@ -681,8 +757,11 @@ void Circuit::saveState()
         }
         m_undoIndex++;
     }
-//qDebug() << "Circuit::saveState Undo:"<< m_undoStack.size()<<m_undoIndex
-//                              <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
+    m_circState.clear();
+
+    clearRemovedComps();
+qDebug() << "Circuit::saveState Undo:"<< m_undoStack.size()<<m_undoIndex
+                              <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
 
 }
 
@@ -705,7 +784,10 @@ void Circuit::addCompState( CompBase* c, QString p, stateMode state )
     if( m_loading || m_deleting ) return;
     QString type = "NULL";
     if( c ) type = c->itemType();
-//qDebug() << "Circuit::addCompState" << type<<p<<state;
+    if ( c )
+        qDebug() << "Circuit::addCompState" << c->getUid() << p << state;
+    else
+        qDebug() << "Circuit::addCompState" << type<<p<<state;
 //qDebug() <<(state&stateNew)<<(state&stateAdd)<<(state&stateSave)<<((int)state&(int)stateSave);
     if( state & stateNew )
     {
@@ -714,38 +796,35 @@ void Circuit::addCompState( CompBase* c, QString p, stateMode state )
     if( state & stateAdd )
     {
         compState cState;
+        Q_ASSERT( c );
         cState.component = c->getUid();
         cState.property  = p;
-        if( p == "new" ) cState.valStr = c->toString();
+        if( p == COMP_STATE_REMOVED ) cState.valStr = c->toString();
         else             cState.valStr = c->getPropStr( p );
 
         if( c->itemType() == "Connector" )
         {
             Connector* con = (Connector*)c;
-            if( p == "remove" )
+            if( p == COMP_STATE_CREATED )
             {
                 cState.valStr = con->startPinId(); // Save Connector start Pin id.
-                m_circState.remove.prepend( cState );
             }
-            else m_circState.create.append( cState );
-        }
-        else               // Component
-        {
-            if( p == "remove" ) m_circState.remove.append( cState );
-            else                m_circState.create.prepend( cState );
         }
+        if ( m_undo ) m_circState.compStates.prepend( cState );
+        else m_circState.compStates.append( cState );
     }
     if( state & stateSave )
     {
 //qDebug() << "Circuit::addCompState saveState";
-        saveState();
+        if( !m_batchProcess )
+            saveState();
     }
 }
 
 void Circuit::undo()
 {
     if( m_busy || m_deleting || m_conStarted || m_undoIndex < 0 ) return;
-//qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_redoIndex;
+qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_redoIndex;
     m_undo = true;
     if( m_undoIndex > m_undoStack.size() )
     {
@@ -757,11 +836,14 @@ void Circuit::undo()
     if( restoreState( step ) )
     {
         m_undoIndex--;
-        m_redoIndex++;
         saveState();
 
         if( m_board && m_board->m_boardMode )
             for( Connector* con : m_conList  ) con->setVisib( false );
+        for( Connector* con : m_conList ) {
+            con->startPin()->isMoved();
+            con->endPin()->isMoved();
+        }
     }
     else clearUndoRedo();
     m_undo = false;
@@ -774,7 +856,7 @@ void Circuit::undo()
 void Circuit::redo()
 {
     if( m_busy || m_deleting || m_conStarted || m_redoIndex < 0 ) return;
-//qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_redoIndex;
+qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_redoIndex;
     m_redo = true;
     if( m_redoIndex > m_redoStack.size() )
     {
@@ -786,11 +868,16 @@ void Circuit::redo()
     if( restoreState( step ) )
     {
         m_redoIndex--;
-        m_undoIndex++;
+        saveState();
         if( m_redoIndex < 0 ) m_redoStack.clear();
 
         if(  m_board && m_board->m_boardMode )
             for( Connector* con : m_conList  ) con->setVisib( false );
+
+        for( Connector* con : m_conList ) {
+            con->startPin()->isMoved();
+            con->endPin()->isMoved();
+        }
     }
     else clearUndoRedo();
     m_redo = false;
@@ -802,80 +889,74 @@ void Circuit::redo()
 
 bool Circuit::restoreState( circState step )
 {
+    beginBatchProcess();
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
     m_busy = true;
 
-    if( m_undo ) addCompState( NULL, "", stateNew ); // Start new Undo/Redo state
+    if( m_undo || m_redo ) addCompState( NULL, "", stateNew ); // Start new Undo/Redo state
 
-    for( compState cState : step.remove )
-    {
-        QString compName = cState.component;
-        CompBase* comp   = m_compMap.value( compName );
-//qDebug() << "Circuit::restoreState"<<compName<<cState.property;
-
-        if( comp && comp->itemType() != "Connector" )
-        {
-            if( m_undo ) addCompState( comp, "new", stateAdd ); // Add compState to new Redo state
-            if( comp->itemType() == "Node")
-            {
-                Node* node = (Node*)comp;
-                if( m_nodeList.contains( node ) ) m_nodeList.removeOne( node );
-                if( node->scene() ) removeItem( node );
-                m_compMap.remove( node->getUid() );
-                delete node;
-            }
-            else removeComp( (Component*)comp );
-        }else{
-            QString propVal  = cState.valStr;
-            Pin* pin = m_pinMap.value( propVal ); // Find Connector start Pin from id.
-            if( !pin ){
-                //qDebug() << "Circuit::restoreState Error NULL Pin"<<compName<<propVal;
-                continue; //return false;
-            }
-            Connector* con = pin->connector();
-            if( !con ){
-                //qDebug() << "Circuit::restoreState Error NULL Connector"<<compName<<propVal;
-                continue; // return false;
-            }
-            if( m_undo )
-            {
-                addCompState( con, "new", stateAdd ); // Add compState to new Redo state
-                con->remove();
-            }
-            else
-            {
-                conList()->removeOne( con );
-                con->remLines();
-                con->startPin()->setConnector( NULL );
-                con->endPin()->setConnector( NULL );
-            }
-        }
+    int iStep, i;
+    if( m_undo ) {
+        iStep = -1; i = step.compStates.size() - 1 ;
+    } else {
+        iStep = 1; i = 0;
     }
-    for( compState cState : step.create )
-    {
+
+    while( i>=0 && i < step.compStates.size() ) {
+        compState cState = step.compStates[i];
+        i += iStep;
         QString compName = cState.component;
         QString propName = cState.property;
         QString propVal  = cState.valStr;
         CompBase* comp   = m_compMap.value( compName );
-//qDebug() << "Circuit::restoreState"<<compName<<propName;
-        if( propName == "new" )
+qDebug() << "Circuit::restoreState"<<compName<<cState.property<<comp;
+
+        if( propName == COMP_STATE_REMOVED )
         {
             loadStrDoc( propVal );
-            if( m_undo && m_newComp ) addCompState( m_newComp, "remove", stateAdd );
-        }
-        else // Property
+            if( m_newComp ) addCompState( m_newComp, COMP_STATE_CREATED, stateAdd );
+        } else if ( propName == COMP_STATE_CREATED ) {
+            if( comp && comp->itemType() != "Connector" )
+            {
+                addCompState( comp, COMP_STATE_REMOVED, stateAdd );
+                if( comp->itemType() == "Node")
+                {
+                    Node* node = (Node*)comp;
+                    removeNode( node );
+                }
+                else removeComp( (Component*)comp );
+            }else{
+                QString propVal  = cState.valStr;
+                Pin* pin = m_pinMap.value( propVal ); // Find Connector start Pin from id.
+                if( !pin ){
+                    //qDebug() << "Circuit::restoreState Error NULL Pin"<<compName<<propVal;
+                    continue; //return false;
+                }
+                Connector* con = pin->connector();
+                if( !con ){
+                    //qDebug() << "Circuit::restoreState Error NULL Connector"<<compName<<propVal;
+                    continue; // return false;
+                }
+                if ( m_conList.contains( con )) {
+                    addCompState( con, COMP_STATE_REMOVED, stateAdd );
+                    removeConnector( con );
+                }
+            }
+
+        } else // Property
         {
             if( !comp ){
-                qDebug() << "Circuit::restoreState Error restoring"<<compName<<propVal;
+                qDebug() << "Circuit::restoreState Error restoring"<<compName<<propName<<propVal;
                 continue;
             }
-            if( m_undo ) addCompState( comp, propName, stateAdd );
+            addCompState( comp, propName, stateAdd );
             comp->setPropStr( propName, propVal );
         }
     }
     m_LdPinMap.clear();
     m_busy = false;
     update();
+    endBatchProcess();
     return true;
 }
 
@@ -925,7 +1006,6 @@ void Circuit::paste( QPointF eventpoint )
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
     bool animate = m_animate;
-    saveState();
     m_busy = true;
     m_pasting = true;
     for( QGraphicsItem*item : selectedItems() ) item->setSelected( false );
@@ -945,6 +1025,7 @@ void Circuit::paste( QPointF eventpoint )
 
 void Circuit::newconnector( Pin* startpin )
 {
+    beginBatchProcess();
     addCompState( NULL, "", stateNew );
     m_conStarted = true;
 
@@ -952,7 +1033,7 @@ void Circuit::newconnector( Pin* startpin )
     QString id = type+"-"+newConnectorId() ;
 
     m_newConnector = new Connector( type, id, startpin );
-    m_conList.append( m_newConnector );
+    m_conList.insert( m_newConnector );
 
     QPoint p1 = startpin->scenePos().toPoint();
     QPoint p2 = startpin->scenePos().toPoint();
@@ -963,14 +1044,15 @@ void Circuit::closeconnector( Pin* endpin )
 {
     m_conStarted = false;
     m_newConnector->closeCon( endpin );
-    addCompState( m_newConnector, "remove", stateAdd );
+    addCompState( m_newConnector, COMP_STATE_CREATED, stateAdd );
     saveState();
+    endBatchProcess();
 }
 
 void Circuit::deleteNewConnector()
 {
     if( !m_conStarted ) return;
-    m_newConnector->remove();
+    removeConnector( m_newConnector );
     m_conStarted = false;
     unSaveState();
 }
@@ -981,7 +1063,7 @@ void Circuit::updateConnectors()
 void Circuit::addNode( Node* node )
 {
     addItem( node );
-    m_nodeList.append( node );
+    m_nodeList.insert( node );
     m_compMap.insert( node->getUid(), node );
 }
 
@@ -1072,7 +1154,7 @@ void Circuit::keyPressEvent( QKeyEvent* event )
         else QGraphicsScene::keyPressEvent( event );
         return;
     }
-    if( event->modifiers() & Qt::AltModifier )
+    if( event->modifiers() & Qt::AltModifier ) // Create Component shortcut
     {
         QString str = event->text();
         if( str.isEmpty() )
@@ -1093,7 +1175,7 @@ void Circuit::keyPressEvent( QKeyEvent* event )
                 QPoint cPos = QCursor::pos()-CircuitView::self()->mapToGlobal( QPoint(0,0));
                 enterItem->setPos( toGrid( CircuitView::self()->mapToScene( cPos ) ) );
                 addItem( enterItem );
-                m_compList.append( enterItem );
+                m_compList.insert( enterItem );
             }
         }
     }
@@ -1138,7 +1220,7 @@ void Circuit::keyPressEvent( QKeyEvent* event )
         }
         else if( key == Qt::Key_R )
         {
-            for( Component* com : m_compList ) if (com->isSelected()) com->rotateCW();
+            for( Component* com : m_compList ) if( com->isSelected() ) com->rotateCW();
         }
         else QGraphicsScene::keyPressEvent( event );
     }
@@ -1198,7 +1280,7 @@ void Circuit::dropEvent( QGraphicsSceneDragDropEvent* event )
                 enterItem->setPos( CircuitView::self()->mapToScene( cPos ) );
                 enterItem->setBackground( file );
                 addItem( enterItem );
-                m_compList.append( enterItem );
+                m_compList.insert( enterItem );
         }   }
         else CircuitWidget::self()->loadCirc( id );
 }   }
