@@ -13,10 +13,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT FlipFlopT : public FlipFlopBase
 {
     public:
-        FlipFlopT( QObject* parent, QString type, QString id );
+        FlipFlopT( QString type, QString id );
         ~FlipFlopT();
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem *libraryItem();
 
     protected:
