@@ -13,10 +13,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT FullAdder : public LogicComponent
 {
     public:
-        FullAdder( QObject* parent, QString type, QString id );
+        FullAdder( QString type, QString id );
         ~FullAdder();
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem* libraryItem();
 
         virtual void stamp() override;
