@@ -14,10 +14,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT XorGate : public Gate
 {
     public:
-        XorGate( QObject* parent, QString type, QString id );
+        XorGate( QString type, QString id );
         ~XorGate();
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem *libraryItem();
 
         virtual QPainterPath shape() const override;
