@@ -28,10 +28,10 @@ class MAINMODULE_EXPORT Transformer : public Component, public eElement
         };
 
     public:
-        Transformer( QObject* parent, QString type, QString id );
+        Transformer( QString type, QString id );
         ~Transformer();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void stamp() override;
