@@ -172,12 +172,8 @@ void SwitchDip::deleteSwitches( int d )
     if( d > m_size ) d = m_size;
     int start = m_size-d;
 
-    for( int i=start*2; i<m_size*2; i++ )
-    {
-        m_pin[i]->removeConnector();
-        m_signalPin.removeAll( m_pin[i] );
-        delete m_pin[i];
-    }
+    for( int i=start*2; i<m_size*2; i++ ) deletePin( m_pin[i] );
+
     for( int i=start; i<m_size; i++ )
     {
         delete m_buttons.takeLast();
