@@ -9,11 +9,12 @@
 #include <QString>
 #include <QProcess>
 
+#include "compbase.h"
+
 class OutPanelText;
 class CodeEditor;
-class CompilerProp;
 
-class Compiler : public QObject
+class Compiler : public QObject, public CompBase
 {
     Q_OBJECT
 
@@ -21,14 +22,11 @@ class Compiler : public QObject
         Compiler( CodeEditor* editor, OutPanelText* outPane );
         ~Compiler();
 
-        void clearCompiler();
-        void loadCompiler( QString file );
-        virtual int compile( bool debug );
-
         QString compName() { return m_compName; }
-        QString fileName() { return m_fileName; }
-        QString buildPath() { return m_buildPath; }
-        QString file() { return m_file ; }
+        void setCompName( QString n ){;} // Dummy
+
+        bool openFiles() { return m_openFiles; }
+        void setOpenFiles( bool o ) { m_openFiles = o; }
 
         virtual QString toolPath() { return m_toolPath; }
         virtual void setToolPath( QString path );
@@ -46,13 +44,32 @@ class Compiler : public QObject
         void setDevice( QString d ) { m_device = d; }
         bool useDevice() { return m_useDevice; }
 
-        void compProps();
+        QString circuit();
+        void setCircuit( QString c );
+
+        QString breakpoints();
+        void setBreakpoints( QString bp );
+
+        QString fileList();
+        void setFileList( QString fl );
+
+        QString fileName() { return m_fileName; }
+        QString buildPath() { return m_buildPath; }
+        QString file() { return m_file ; }
+
+        void clearCompiler();
+        void loadCompiler( QString file );
+        virtual int compile( bool debug );
+
+        virtual QString toString() override;
+
+        virtual PropDialog* compilerProps();
 
         bool isProjectFile( QString file ) { return m_fileList.contains( file ); }
 
         void readSettings();
 
-        virtual void getInfoInFile( QString line ){;}
+        virtual void getInfoInFile( QString line ){;}  /// TODELETE
 
         bool checkCommand( QString c );
 
@@ -72,12 +89,12 @@ class Compiler : public QObject
         QString getPath( QString msg, QString oldPath );
         void toolChainNotFound();
 
-        CompilerProp* m_compDialog;
         CodeEditor* m_editor;
 
         bool m_useFamily;
         bool m_useDevice;
         bool m_uploadHex;
+        bool m_openFiles;
 
         QString m_compName;
         QString m_toolPath;
@@ -91,7 +108,6 @@ class Compiler : public QObject
         QString m_type;
         QString m_family;
         QString m_device;
-        QString m_board;
         QString m_firmware;
         QString m_file;
         QString m_fileDir;
