@@ -20,9 +20,6 @@ class CompilerProp : public QDialog, private Ui::CompilerProp
         CompilerProp( CodeEditor* parent );
 
         void setCompiler( Compiler* compiler );
-        void setFamily( QString fam );
-        void setDevice( QString dev );
-        //void setBoard( int index );
 
     public slots:
         void on_compilerBox_currentIndexChanged( int index );
@@ -33,15 +30,7 @@ class CompilerProp : public QDialog, private Ui::CompilerProp
         void on_toolPath_editingFinished();
         void on_inclPath_editingFinished();
 
-        void on_familyText_editingFinished();
-        void on_deviceText_editingFinished();
-
-        void on_ardBoard_currentIndexChanged( int index );
-        void on_customBoard_textEdited( QString board );
-
     private:
-        void updateDialog();
-
         CodeEditor* m_document;
         Compiler* m_compiler;
 
