@@ -30,9 +30,11 @@ class EditorWidget : public QWidget
 
        CodeEditor* getCodeEditor();
 
+       QStringList getFiles() { return m_fileList.keys(); }
+       void restoreFile( QString filePath );
 
     public slots:
-       void loadFile( const QString &fileName );
+       void loadFile( QString filePath );
        bool save();
        virtual void pause(){;}
        virtual void stop(){;}
@@ -51,7 +53,6 @@ class EditorWidget : public QWidget
         void documentWasModified();
         void tabChanged( int tab );
 
-
         void cut()   { getCodeEditor()->cut(); }
         void copy()  { getCodeEditor()->copy(); }
         void paste() { getCodeEditor()->paste(); }
@@ -66,7 +67,6 @@ class EditorWidget : public QWidget
 
         virtual bool upload() {return false;}
 
-
     protected:
         void dropEvent( QDropEvent* event );
         void dragEnterEvent( QDragEnterEvent* event);
@@ -84,12 +84,13 @@ class EditorWidget : public QWidget
         void setStepActs( bool s );
 
         enum { MaxRecentFiles = 10 };
+        void addRecentFile( QString filePath );
         void updateRecentFileActions();
 
         bool maybeSave();
-        bool saveFile( const QString &fileName );
-        void saveBreakpoints( QString fileName );
-        void loadBreakpoints( const QString &fileName );
+        bool saveFile( QString fileName );
+
+        void addDocument( QString file, bool main );
 
         OutPanelText m_outPane;
 
